Class: Aws::Lex::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Lex::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-lex/client.rb,
sig/client.rbs
Overview
An API client for Lex. To construct a client, you need to configure a :region and :credentials.
client = Aws::Lex::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DeleteSessionResponseSuccess, _GetSessionResponseSuccess, _PostContentResponseSuccess, _PostTextResponseSuccess, _PutSessionResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_session(params = {}) ⇒ Types::DeleteSessionResponse
Removes session information for a specified bot, alias, and user ID.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Returns session information for a specified bot, alias, and user ID.
-
#post_content(params = {}) ⇒ Types::PostContentResponse
Sends user input (text or speech) to Amazon Lex.
-
#post_text(params = {}) ⇒ Types::PostTextResponse
Sends user input to Amazon Lex.
-
#put_session(params = {}) ⇒ Types::PutSessionResponse
Creates a new session or modifies an existing session with an Amazon Lex bot.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-lex/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1292 1293 1294 |
# File 'lib/aws-sdk-lex/client.rb', line 1292 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1295 1296 1297 |
# File 'lib/aws-sdk-lex/client.rb', line 1295 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-lex/client.rb', line 1265 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Lex') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-lex' context[:gem_version] = '1.98.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_session(params = {}) ⇒ Types::DeleteSessionResponse
Removes session information for a specified bot, alias, and user ID.
89 |
# File 'sig/client.rbs', line 89 def delete_session: ( |
#get_session(params = {}) ⇒ Types::GetSessionResponse
Returns session information for a specified bot, alias, and user ID.
105 |
# File 'sig/client.rbs', line 105 def get_session: ( |
#post_content(params = {}) ⇒ Types::PostContentResponse
Sends user input (text or speech) to Amazon Lex. Clients use this API to send text and audio requests to Amazon Lex at runtime. Amazon Lex interprets the user input using the machine learning model that it built for the bot.
The PostContent operation supports audio input at 8kHz and 16kHz.
You can use 8kHz audio to achieve higher speech recognition accuracy
in telephone audio applications.
In response, Amazon Lex returns the next message to convey to the user. Consider the following example messages:
-
For a user input "I would like a pizza," Amazon Lex might return a response with a message eliciting slot data (for example,
PizzaSize): "What size pizza would you like?". -
After the user provides all of the pizza order information, Amazon Lex might return a response with a message to get user confirmation: "Order the pizza?".
-
After the user replies "Yes" to the confirmation prompt, Amazon Lex might return a conclusion statement: "Thank you, your cheese pizza has been ordered.".
Not all Amazon Lex messages require a response from the user. For
example, conclusion statements do not require a response. Some
messages require only a yes or no response. In addition to the
message, Amazon Lex provides additional context about the message in
the response that you can use to enhance client behavior, such as
displaying the appropriate client user interface. Consider the
following examples:
-
If the message is to elicit slot data, Amazon Lex returns the following context information:
-
x-amz-lex-dialog-stateheader set toElicitSlot -
x-amz-lex-intent-nameheader set to the intent name in the current context -
x-amz-lex-slot-to-elicitheader set to the slot name for which themessageis eliciting information -
x-amz-lex-slotsheader set to a map of slots configured for the intent with their current values -
If the message is a confirmation prompt, the
x-amz-lex-dialog-stateheader is set toConfirmationand thex-amz-lex-slot-to-elicitheader is omitted. -
If the message is a clarification prompt configured for the intent, indicating that the user intent is not understood, the
x-amz-dialog-stateheader is set toElicitIntentand thex-amz-slot-to-elicitheader is omitted.
In addition, Amazon Lex also returns your application-specific
sessionAttributes. For more information, see Managing Conversation
Context.
135 |
# File 'sig/client.rbs', line 135 def post_content: ( |
#post_text(params = {}) ⇒ Types::PostTextResponse
Sends user input to Amazon Lex. Client applications can use this API to send requests to Amazon Lex at runtime. Amazon Lex then interprets the user input using the machine learning model it built for the bot.
In response, Amazon Lex returns the next message to convey to the
user an optional responseCard to display. Consider the following
example messages:
-
For a user input "I would like a pizza", Amazon Lex might return a response with a message eliciting slot data (for example, PizzaSize): "What size pizza would you like?"
-
After the user provides all of the pizza order information, Amazon Lex might return a response with a message to obtain user confirmation "Proceed with the pizza order?".
-
After the user replies to a confirmation prompt with a "yes", Amazon Lex might return a conclusion statement: "Thank you, your cheese pizza has been ordered.".
Not all Amazon Lex messages require a user response. For example, a
conclusion statement does not require a response. Some messages
require only a "yes" or "no" user response. In addition to the
message, Amazon Lex provides additional context about the message in
the response that you might use to enhance client behavior, for
example, to display the appropriate client user interface. These are
the slotToElicit, dialogState, intentName, and slots fields in
the response. Consider the following examples:
-
If the message is to elicit slot data, Amazon Lex returns the following context information:
-
dialogStateset to ElicitSlot -
intentNameset to the intent name in the current context -
slotToElicitset to the slot name for which themessageis eliciting information -
slotsset to a map of slots, configured for the intent, with currently known values -
If the message is a confirmation prompt, the
dialogStateis set to ConfirmIntent andSlotToElicitis set to null. -
If the message is a clarification prompt (configured for the intent) that indicates that user intent is not understood, the
dialogStateis set to ElicitIntent andslotToElicitis set to null.
In addition, Amazon Lex also returns your application-specific
sessionAttributes. For more information, see Managing Conversation
Context.
166 |
# File 'sig/client.rbs', line 166 def post_text: ( |
#put_session(params = {}) ⇒ Types::PutSessionResponse
Creates a new session or modifies an existing session with an Amazon Lex bot. Use this operation to enable your application to set the state of the bot.
For more information, see Managing Sessions.
195 |
# File 'sig/client.rbs', line 195 def put_session: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1285 1286 1287 |
# File 'lib/aws-sdk-lex/client.rb', line 1285 def waiter_names [] end |