Class: Aws::Lex::Types::PutSessionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lex::Types::PutSessionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lex/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:message, :encoded_message, :active_contexts]
Instance Attribute Summary collapse
-
#active_contexts ⇒ String
A list of active contexts for the session.
-
#audio_stream ⇒ IO
The audio version of the message to convey to the user.
-
#content_type ⇒ String
Content type as specified in the
AcceptHTTP header in the request. -
#dialog_state ⇒ String
-
ConfirmIntent- Amazon Lex is expecting a “yes” or “no” response to confirm the intent before fulfilling an intent.
-
-
#encoded_message ⇒ String
The next message that should be presented to the user.
-
#intent_name ⇒ String
The name of the current intent.
-
#message ⇒ String
The next message that should be presented to the user.
-
#message_format ⇒ String
The format of the response message.
-
#session_attributes ⇒ String
Map of key/value pairs representing session-specific context information.
-
#session_id ⇒ String
A unique identifier for the session.
-
#slot_to_elicit ⇒ String
If the
dialogStateisElicitSlot, returns the name of the slot for which Amazon Lex is eliciting a value. -
#slots ⇒ String
Map of zero or more intent slots Amazon Lex detected from the user input during the conversation.
Instance Attribute Details
#active_contexts ⇒ String
A list of active contexts for the session.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#audio_stream ⇒ IO
The audio version of the message to convey to the user.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#content_type ⇒ String
Content type as specified in the Accept HTTP header in the request.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#dialog_state ⇒ String
-
ConfirmIntent- Amazon Lex is expecting a “yes” or “no” response to confirm the intent before fulfilling an intent. -
ElicitIntent- Amazon Lex wants to elicit the user’s intent. -
ElicitSlot- Amazon Lex is expecting the value of a slot for the current intent. -
Failed- Conveys that the conversation with the user has failed. This can happen for various reasons, including the user does not provide an appropriate response to prompts from the service, or if the Lambda function fails to fulfill the intent. -
Fulfilled- Conveys that the Lambda function has sucessfully fulfilled the intent. -
ReadyForFulfillment- Conveys that the client has to fulfill the intent.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#encoded_message ⇒ String
The next message that should be presented to the user.
The encodedMessage field is base-64 encoded. You must decode the field before you can use the value.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#intent_name ⇒ String
The name of the current intent.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#message ⇒ String
The next message that should be presented to the user.
You can only use this field in the de-DE, en-AU, en-GB, en-US, es-419, es-ES, es-US, fr-CA, fr-FR, and it-IT locales. In all other locales, the message field is null. You should use the encodedMessage field instead.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#message_format ⇒ String
The format of the response message. One of the following values:
-
PlainText- The message contains plain UTF-8 text. -
CustomPayload- The message is a custom format for the client. -
SSML- The message contains text formatted for voice output. -
Composite- The message contains an escaped JSON object containing one or more messages from the groups that messages were assigned to when the intent was created.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#session_attributes ⇒ String
Map of key/value pairs representing session-specific context information.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#session_id ⇒ String
A unique identifier for the session.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#slot_to_elicit ⇒ String
If the dialogState is ElicitSlot, returns the name of the slot for which Amazon Lex is eliciting a value.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |
#slots ⇒ String
Map of zero or more intent slots Amazon Lex detected from the user input during the conversation.
Amazon Lex creates a resolution list containing likely values for a slot. The value that it returns is determined by the valueSelectionStrategy selected when the slot type was created or updated. If valueSelectionStrategy is set to ORIGINAL_VALUE, the value provided by the user is returned, if the user value is similar to the slot values. If valueSelectionStrategy is set to TOP_RESOLUTION Amazon Lex returns the first value in the resolution list or, if there is no resolution list, null. If you don’t specify a valueSelectionStrategy the default is ORIGINAL_VALUE.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/aws-sdk-lex/types.rb', line 1519 class PutSessionResponse < Struct.new( :content_type, :intent_name, :slots, :session_attributes, :message, :encoded_message, :message_format, :dialog_state, :slot_to_elicit, :audio_stream, :session_id, :active_contexts) SENSITIVE = [:message, :encoded_message, :active_contexts] include Aws::Structure end |